.. Copyright (c) 2016, Johan Mabille and Sylvain Corlay

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

API reference
=============

Containers
----------

.. toctree::
   :maxdepth: 2

   pyarray
   pytensor

Numpy universal functions
-------------------------

.. toctree::
   :maxdepth: 2

   pyvectorize
